// Import the DSS packages into our namespace to save on typing
importPackage(Packages.com.ti.debug.engine.scripting);
importPackage(Packages.com.ti.ccstudio.scripting.environment);
importPackage(Packages.java.lang);

// Modify these variables to match your environment. Use forward slashes
var ccs5InstallDir = "C:/ti";
var DSSWorkshopDir = "C:/CCSWorkshop/dss"
var deviceCCXMLFile = DSSWorkshopDir + "/lab3/StellarisLaunchPad.ccxml";
var programToLoad = DSSWorkshopDir + "/lab3/modem.out";
var logFile = DSSWorkshopDir + "/lab3/log.xml";

// Create our scripting environment object - which is the main entry point 
// into any script and the factory for creating other Scriptable Servers and Sessions
var script = ScriptingEnvironment.instance();

// Create a log file in the current directory to log script execution
script.traceBegin(logFile, ccs5InstallDir + "/ccsv6/ccs_base/scripting/examples/DebugServerExamples/DefaultStylesheet.xsl");

// Set trace levels for console and logs
script.traceSetConsoleLevel(TraceLevel.INFO);
script.traceSetFileLevel(TraceLevel.ALL);

script.traceWrite("Begin scripting session");

// Get the Debug Server and start a Debug Session
var debugServer = script.getServer("DebugServer.1");
debugServer.setConfig(deviceCCXMLFile);
var debugSession = debugServer.openSession(".*");

// Connect to the CPU
debugSession.target.connect();

try {
// Load a program
debugSession.memory.loadProgram(programToLoad); 
} catch (ex){
    script.traceWrite("Program load of " + 
	programToLoad + " failed! Terminating script.");         
    quit();
}

// Run the target
debugSession.target.run();

// All done
debugServer.stop();

script.traceWrite("End scripting session");

// Stop logging and exit.
script.traceEnd();

